@@ -156,9 +156,11 @@ class SqlStore:
             return farm
 
     def get_db_by_table(self, table):
-        farm = self.tables.get(table)
+        tables = self.tables
+        farm = tables.get(table)
         if farm is None:
-            raise Exception("%s TABLE NOT CONFIGURE" % table)
+            print "%s TABLE NOT CONFIGURE" % table
+            return tables['*']
         else:
             return farm
 
